//
//  GameParametersMenuView.swift
//  ArkitDoushiQi
//
//  Created by Johan LACHENAL on 24/05/2024.
//

import SwiftUI
import PhotosUI

struct GameParametersMenuView: View, KeyboardReadable {
    @State private var selectedGameType: GameType = .PvP
    @State private var selectedAIOption: AI = .RandomAction
    @State private var selectedRulesOption: Rules = .Regular
    @State private var isKeyboardVisible = false
    
    var body: some View {
        NavigationView {
            VStack(alignment: .leading) {
                HStack(alignment: .center) {
                    Text(LocalizedStringKey("Paramètres de partie")).bold().font(.title)
                }.frame(maxWidth: .infinity)
                
                // Sélecteur pour le type de partie
                PickerComponent(title: LocalizedStringKey("Sélectionne le type de partie :"),
                                selectedOption: $selectedGameType,
                                options: GameType.allCases)
                
                PickerComponent(title: LocalizedStringKey("Sélectionne les règles :"),
                                selectedOption: $selectedRulesOption,
                                options: Rules.allCases)
                
                if selectedGameType == .PvAI {
                    PickerComponent(title: LocalizedStringKey("Sélectionne une IA :"),
                                    selectedOption: $selectedAIOption,
                                    options: AI.allCases)
                }
                
                ProfileEdit(color: Color(.red), profileWidth: 100, profileHeight: 100, defaultImage: Image("profil"), imageTextChange: LocalizedStringKey("changer l'avatar du joueur 1"), playerNameKey: LocalizedStringKey("Nom du Joueur 1"))
                
                if selectedGameType == .PvP {
                    ProfileEdit(color: Color(.blue), profileWidth: 100, profileHeight: 100, defaultImage: Image("profil"), imageTextChange: LocalizedStringKey("changer l'avatar du joueur 2"), playerNameKey: LocalizedStringKey("Nom du Joueur 2"))
                }
                
                if !isKeyboardVisible {
                    ButtonComponent(title: LocalizedStringKey("Lancer la partie")) {
                        GameView()
                    }.padding(EdgeInsets(top: 10, leading: 32, bottom: 10, trailing: 32))
                }
            }
            .onReceive(keyboardPublisher) { value in isKeyboardVisible = value }
            .frame(maxHeight: .infinity, alignment: .top)
        }
    }
}

struct GameParametersMenuView_Previews: PreviewProvider {
    static var previews: some View {
        GameParametersMenuView()
    }
}
